==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/sr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Задаци",
    "Due yesterday" : "до јуче",
    "Due today" : "до данас",
    "Due tomorrow" : "до сутра",
    "Due on" : "рок",
    "Started yesterday" : "започет јуче",
    "Starts today" : "почиње данас",
    "Starts tomorrow" : "почиње сутра",
    "Started on" : "почео",
    "Starts on" : "почиње",
    "[Remind me yesterday at ]HH:mm" : "[Подсети ме јуче у ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Подсети ме данас у ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Подсети ме сутра у ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Подсети ме ]DD MMM YYYY[ у ]HH:mm",
    "Yesterday" : "јуче",
    "Today" : "Данас",
    "Tomorrow" : "сутра",
    "in %s" : "за %s",
    "%s ago" : "пре %s",
    "seconds" : "секунди",
    "a minute" : "минут",
    "%d minutes" : "%d минута",
    "an hour" : "сат",
    "%d hours" : "%d ч",
    "a day" : "дан",
    "%d days" : "%d дана",
    "a month" : "месец",
    "%d months" : "%d мес.",
    "a year" : "година",
    "%d years" : "%d год.",
    "Hours" : "сати",
    "Minutes" : "минути",
    "week" : "седмица",
    "weeks" : "седмица",
    "day" : "дан",
    "days" : "дана",
    "hour" : "сат",
    "hours" : "сати",
    "minute" : "минут",
    "minutes" : "минута",
    "second" : "секунд",
    "before beginning" : "пре почетка",
    "after beginning" : "након почетка",
    "before end" : "пре завршетка",
    "after end" : "након завршетка",
    "Comment" : "Коментар",
    "Add a comment" : "Додајте коментар",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ово ће обрисати календар „%s“ и све његове уносе.",
    "The name \"%s\" is already used." : "Назив „%s“ се већ користи.",
    "An empty name is not allowed." : "Празан назив није дозвољен.",
    "Hidden" : "Сакривен",
    "Visible" : "Видљив",
    "Automatic" : "Аутоматски",
    "Sunday" : "недеља",
    "Monday" : "понедељак",
    "Tuesday" : "уторак",
    "Wednesday" : "среда",
    "Thursday" : "четвртак",
    "Friday" : "петак",
    "Saturday" : "субота",
    "Add an important item in \"%s\"..." : "Додај важну ставку у „%s“...",
    "Add an item due today in \"%s\"..." : "Додај рок ставке за данас у „%s“...",
    "Add an item in \"%s\"..." : "Додај ставку у „%s“...",
    "Add a current item in \"%s\"..." : "Додај тренутну ставку у „%s“...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завршен задатак","%n завршена задатка","%n завршених задатака"],
    "Set due date" : "Постави датум рока",
    "%s %% completed" : "%s %% завршено",
    "Remind me" : "Подсети ме",
    "at the end" : "на крају",
    "at the beginning" : "на почетку",
    "Set start date" : "Постави датум почетка",
    "Important" : "Важно",
    "Week" : "Недеља",
    "All" : "Све",
    "Current" : "Текуће",
    "Completed" : "Завршено",
    "rename" : "преименуј",
    "delete" : "обриши",
    "Add List..." : "Додај листу...",
    "New List" : "Нова листа",
    "Settings" : "Поставке",
    "Start of week" : "Почетак недеље",
    "Visibility of Smart Collections" : "Видљивост паметних збирки",
    "Load remaining completed tasks." : "Учитај преостале довршене задатке.",
    "(New category)" : "(Нова категорија)",
    "Select categories..." : "Изаберите категорије...",
    "Loading the task..." : "Учитавам задатке...",
    "Task not found!" : "Задатак није пронађен!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/sr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Задаци",
    "Tasks app is unavailable because the calendar is not installed" : "Апликација Задаци није доступна јер Календар није инсталиран",
    "Due yesterday" : "до јуче",
    "Due today" : "до данас",
    "Due tomorrow" : "до сутра",
    "Due on" : "рок",
    "Started yesterday" : "започет јуче",
    "Starts today" : "почиње данас",
    "Starts tomorrow" : "почиње сутра",
    "Started on" : "почео",
    "Starts on" : "почиње",
    "[Remind me yesterday at ]HH:mm" : "[Подсети ме јуче у ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Подсети ме данас у ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Подсети ме сутра у ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Подсети ме ]DD MMM YYYY[ у ]HH:mm",
    "Yesterday" : "јуче",
    "Today" : "Данас",
    "Tomorrow" : "сутра",
    "in %s" : "за %s",
    "%s ago" : "пре %s",
    "seconds" : "секунди",
    "a minute" : "минут",
    "%d minutes" : "%d минута",
    "an hour" : "сат",
    "%d hours" : "%d ч",
    "a day" : "дан",
    "%d days" : "%d дана",
    "a month" : "месец",
    "%d months" : "%d мес.",
    "a year" : "година",
    "%d years" : "%d год.",
    "Hours" : "сати",
    "Minutes" : "минути",
    "week" : "седмица",
    "weeks" : "седмица",
    "day" : "дан",
    "days" : "дана",
    "hour" : "сат",
    "hours" : "сати",
    "minute" : "минут",
    "minutes" : "минута",
    "second" : "секунд",
    "before beginning" : "пре почетка",
    "after beginning" : "након почетка",
    "before end" : "пре завршетка",
    "after end" : "након завршетка",
    "Comment" : "Коментар",
    "Add a comment" : "Додајте коментар",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ово ће обрисати календар „%s“ и све његове уносе.",
    "The name \"%s\" is already used." : "Назив „%s“ се већ користи.",
    "An empty name is not allowed." : "Празан назив није дозвољен.",
    "Hidden" : "Сакривен",
    "Visible" : "Видљив",
    "Automatic" : "Аутоматски",
    "Sunday" : "недеља",
    "Monday" : "понедељак",
    "Tuesday" : "уторак",
    "Wednesday" : "среда",
    "Thursday" : "четвртак",
    "Friday" : "петак",
    "Saturday" : "субота",
    "Add an important item in \"%s\"..." : "Додај важну ставку у „%s“...",
    "Add an item due today in \"%s\"..." : "Додај рок ставке за данас у „%s“...",
    "Add an item in \"%s\"..." : "Додај ставку у „%s“...",
    "Add a current item in \"%s\"..." : "Додај тренутну ставку у „%s“...",
    "Add a subtask to \"%s\"..." : "Додај подзадатак у „%s“...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завршен задатак","%n завршена задатка","%n завршених задатака"],
    "Set due date" : "Постави датум рока",
    "%s %% completed" : "%s %% завршено",
    "priority %s: " : "приоритет %s:",
    "high" : "висок",
    "medium" : "средњи",
    "low" : "низак",
    "no priority assigned" : "није додељен приоритет",
    "Remind me" : "Подсети ме",
    "at the end" : "на крају",
    "at the beginning" : "на почетку",
    "Set start date" : "Постави датум почетка",
    "Important" : "Важно",
    "Week" : "Недеља",
    "All" : "Све",
    "Current" : "Текуће",
    "Completed" : "Завршено",
    "rename" : "преименуј",
    "delete" : "обриши",
    "Add List..." : "Додај листу...",
    "New List" : "Нова листа",
    "Settings" : "Поставке",
    "Start of week" : "Почетак недеље",
    "Visibility of Smart Collections" : "Видљивост паметних збирки",
    "Load remaining completed tasks." : "Учитај преостале довршене задатке.",
    "(New category)" : "(Нова категорија)",
    "Select categories..." : "Изаберите категорије...",
    "Loading the task..." : "Учитавам задатке...",
    "Task not found!" : "Задатак није пронађен!",
    "add a subtask to" : "додај подзадатак"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
